[![travis auto testing](https://travis-ci.org/liusida/sida.svg?branch=master)](https://travis-ci.org/liusida/sida/builds/591700653)

# sida
personal package to pip

# Installation

```python
pip install sida
```

# Talk Notes

Here are [Note](notes.md)

How To Publish A Package On PyPI
by Mark Smith 